@@ -1,25 +1,33 @@
-package GD::Graph::radar;
-our $AUTHORITY = 'cpan:GENE';
+#==============================================
+#    Copyright (c) 2003 Brad Murray
+#----------------------------------------------
+#
+#    Name: GD::Graph::radar.pm
+#
+#==============================================
 
-# ABSTRACT: (DEPRECATED) Attempt to make radial charts
+package GD::Graph::radar;
+
+$GD::Graph::pie::VERSION = '0.02';
 
 use strict;
-use warnings;
-
-our $VERSION = '0.1105_2';
-
-use base qw(GD::Graph);
-use GD;
-use GD::Graph::colour qw(:colours :lists);
-use GD::Graph::utils qw(:all);
-use GD::Text::Align;
 
 use constant PI => 4 * atan2(1, 1);
-use constant ANGLE_OFFSET => 90;
 
+use GD;
+use GD::Graph;
+use GD::Graph::utils qw(:all);
+use GD::Graph::colour qw(:colours :lists);
+use GD::Text::Align;
+use Carp;
+
+@GD::Graph::radar::ISA = qw(GD::Graph);
+
+my $ANGLE_OFFSET = 90;
 
 my %Defaults = (
-    # The angle at which to start the first data set 0 is pointing straight down
+    # The angle at which to start the first data set
+    # 0 is pointing straight down
     start_angle => 0,
 
     # and some public attributes without defaults
@@ -42,59 +50,62 @@ my %Defaults = (
     poly_fill => '#e4e4e4',
 );
 
+# PRIVATE
 sub _has_default { 
     my $self = shift;
     my $attr = shift || return;
     exists $Defaults{$attr} || $self->SUPER::_has_default($attr);
 }
 
+sub initialise {
+    my $self = shift;
+    $self->SUPER::initialise();
+    while (my ($key, $val) = each %Defaults) {
+        $self->{$key} = $val;
+    }
+    $self->set_value_font(gdTinyFont);
+    $self->set_label_font(gdSmallFont);
+}
 
+# PUBLIC methods, documented in pod
 sub plot {
     my $self = shift;
     my $data = shift;
 
     $self->check_data($data) or return;
     $self->init_graph()      or return;
-    $self->_setup_text()     or return;
-    $self->_setup_coords()   or return;
-    $self->_draw_text()      or return;
-    $self->_draw_data()      or return;
+    $self->setup_text()      or return;
+    $self->setup_coords()    or return;
+    $self->draw_text()       or return;
+    $self->draw_data()       or return;
 
     return $self->{graph};
 }
 
-
-sub initialise {
-    my $self = shift;
-
-    $self->SUPER::initialise();
-
-    while (my ($key, $val) = each %Defaults) {
-        $self->{$key} = $val;
-    }
-
-    $self->_set_value_font(gdTinyFont);
-    $self->_set_label_font(gdSmallFont);
-}
-
-sub _set_label_font {
+sub set_label_font {  # (fontname)
     my $self = shift;
     $self->_set_font('gdta_label', @_) or return;
     $self->{gdta_label}->set_align('bottom', 'center');
 }
 
-sub _set_value_font {
+sub set_value_font {  # (fontname)
     my $self = shift;
     $self->_set_font('gdta_value', @_) or return;
     $self->{gdta_value}->set_align('center', 'center');
 }
 
-sub _setup_coords() {
-    # Inherit defaults() from GD::Graph
-    # Inherit checkdata from GD::Graph
+# Inherit defaults() from GD::Graph
+
+# inherit checkdata from GD::Graph
+
+# Setup the coordinate system and colours, calculate the
+# relative axis coordinates in respect to the canvas size.
+
+sub setup_coords() {
     my $self = shift;
 
     # Make sure we're not reserving space we don't need.
+
     my $tfh = $self->{title} ? $self->{gdta_title}->get('height') : 0;
     my $lfh = $self->{label} ? $self->{gdta_label}->get('height') : 0;
 
@@ -124,8 +135,10 @@ sub _setup_coords() {
     return $self;
 }
 
-sub _setup_text {
-    # Inherit open_graph from GD::Graph
+# inherit open_graph from GD::Graph
+
+# Setup the parameters for the text elements
+sub setup_text {
     my $self = shift;
 
     if ($self->{title}) {
@@ -144,7 +157,8 @@ sub _setup_text {
     return $self;
 }
 
-sub _draw_text {
+# Put the text on the canvas.
+sub draw_text {
     my $self = shift;
 
     $self->{gdta_title}->draw($self->{xc}, $self->{t_margin}) 
@@ -155,7 +169,9 @@ sub _draw_text {
     return $self;
 }
 
-sub _draw_data {
+# Draw the data lines and the polygon
+
+sub draw_data {
     my $self = shift;
 
     my $max_val = 0;
@@ -168,14 +184,17 @@ sub _draw_data {
         if ($_ < $min_val) { $min_val = $_; }
     }
 
-    $scale = $self->{absolute}
-        ? ($self->{w} / 2) / $max_val
-        : ($self->{w} / 2) / ($max_val - $min_val);
+    if ($self->{absolute}) {
+        $scale = ($self->{w} / 2) / $max_val;
+    }
+    else {
+        $scale = ($self->{w} / 2) / ($max_val - $min_val);
+    }
        
     my $ac = $self->{acci};  # Accent colour
     my $pb = $self->{start_angle};
 
-    my $poly = GD::Polygon->new;
+    my $poly = new GD::Polygon;
     my @vertices = ();
 
     for (my $i = 0; $i < @values; $i++) {
@@ -196,41 +215,40 @@ sub _draw_data {
         # Calculate the end points of the lines at the boundaries of
         # the pie slice
         my $radius = $values[$i] * $scale;
-
-        $radius = 0 if $radius < 0 && $self->{absolute};
-
-        my ($xe, $ye) = _cartesian(
+        if ($radius < 0 && $self->{absolute}) {
+            $radius = 0;
+        }
+        my ($xe, $ye) = cartesian(
             $radius,
             $pa, 
             $self->{xc}, $self->{yc},
             $self->{h} / $self->{w}
         );
+        if ($self->{polygon}) {
+            $poly->addPt($xe, $ye);
+        }
+        push(@vertices, [$xe, $ye]);
 
-        $poly->addPt($xe, $ye) if $self->{polygon};
-
-        push @vertices, [$xe, $ye];
     }
 
     # draw the apex polygon
     $self->{graph}->polygon($poly, $ac);
-
     if (defined $self->{poly_fill}) {
         my ($r, $g, $b) = GD::Graph::colour::hex2rgb($self->{poly_fill});
-
         my $fc = $self->{graph}->colorAllocate($r, $g, $b);
-
         $self->{graph}->fill($self->{xc}, $self->{yc}, $fc);
     }
 
-    # draw markers
+        # draw markers
     my $mark_incr = 1;
-    $mark_incr = $self->{absolute}
-        ? int ($max_val / $self->{nmarkers})
-        : int (($max_val - $min_val) / $self->{nmarkers});
-
+    if ($self->{absolute}) {
+        $mark_incr = int ($max_val / $self->{nmarkers});
+    }
+    else {
+        $mark_incr = int (($max_val - $min_val) / $self->{nmarkers});
+    }
     for (1 .. $self->{nmarkers}) {
         my $width = 2 * $_ * $mark_incr * $scale;
-
         $self->{graph}->arc(
             $self->{xc}, $self->{yc},
             $width,
@@ -242,7 +260,6 @@ sub _draw_data {
 
     # draw radar value bars
     my $dc = $self->{graph}->colorAllocate(0, 0, 0);
-
     for (@vertices) {
         $self->{graph}->line(
             $self->{xc}, $self->{yc},
@@ -253,7 +270,6 @@ sub _draw_data {
 
     # draw labels
     $pb = $self->{start_angle};
-
     for (my $i = 0; $i < @values; $i++) {
         next unless $values[$i];
 
@@ -262,19 +278,21 @@ sub _draw_data {
 
         next if $self->{suppress_angle} && $slice_angle <= $self->{suppress_angle};
 
-        my ($xe, $ye) = _cartesian(
+        my ($xe, $ye) = cartesian(
               3 * $self->{w} / 8, $pa,
               $self->{xc}, $self->{yc},
               $self->{h} / $self->{w}
         );
 
-        $self->_put_slice_label($xe, $ye, $self->{_data}->get_x($i));
+        $self->put_slice_label($xe, $ye, $self->{_data}->get_x($i));
     }
        
     return $self;
-}
 
-sub _put_slice_label {
+}  #GD::Graph::radar::draw_data
+
+# put the slice label on the pie
+sub put_slice_label {
     my $self = shift;
     my ($x, $y, $label) = @_;
 
@@ -284,12 +302,16 @@ sub _put_slice_label {
     $self->{gdta_value}->draw($x, $y);
 }
 
-sub _cartesian {
-    # $ANGLE_OFFSET is used to define where 0 is meant to be
+# return x, y coordinates from input
+# radius, angle, center x and y and a scaling factor (height/width)
+#
+# $ANGLE_OFFSET is used to define where 0 is meant to be
+sub cartesian {
     my ($r, $phi, $xi, $yi, $cr) = @_; 
+
     return (
-        $xi + $r * cos (PI * ($phi + ANGLE_OFFSET) / 180),
-        $yi + $cr * $r * sin (PI * ($phi + ANGLE_OFFSET) / 180)
+        $xi + $r * cos(PI * ($phi + $ANGLE_OFFSET) / 180),
+        $yi + $cr * $r * sin(PI * ($phi + $ANGLE_OFFSET) / 180)
     )
 }
 
@@ -297,81 +319,57 @@ sub _cartesian {
 
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
-GD::Graph::radar - (DEPRECATED) Attempt to make radial charts
-
-=head1 VERSION
-
-version 0.1105_2
+GD::Graph::radar - Make radial bar charts
 
 =head1 SYNOPSIS
 
   use GD::Graph::radar;
-
   my $radar = GD::Graph::radar->new(400, 400);
-
   my $image = $radar->plot([
-      [qw( a    b  c    d    e    f    g  h    i )],
-      [qw( 3.2  9  4.4  3.9  4.1  4.3  7  6.1  5 )]
+      [ qw( a    b  c    d    e    f    g  h    i )],
+      [     3.2, 9, 4.4, 3.9, 4.1, 4.3, 7, 6.1, 5  ]
   ]);
 
-  print $image->png;  # or ->gif or ->jpeg or ...
+  binmode STDOUT;
+  $filename = "$0.png";
+  open PNG, ">$filename" or die "Can't open $filename - $!\n";
+  binmode PNG;
+  print PNG $image->png;
+  close PNG;
 
 =head1 DESCRIPTION
 
-This module is B<DEPRECATED> and is based on L<GD::Graph::pie> but
-B<attempts> to draw a radar chart instead.  Apparently the code only
-allows you to draw at most nine unlabeled concentric scale circles.
-Ugh!
+This module is based on C<GD::Graph::pie> with the exception of 
+changes to the default settings, the C<draw_data> method, and 
+elimination of the pie specific code.
 
-Please check out the L<Radial> module instead.
+=head1 ABSTRACT
 
-=head1 METHODS
-
-=head2 new()
-
-  $radar = GD::Graph::radar->new($height, $width);
-
-Create a new C<GD::Graph::radar> object.
-
-=head2 plot()
-
-  $image = $radar->plot(\@data);
-
-Create the image.
-
-=head2 initialise()
-
-Setup the plot.
+Make radial bar charts
 
 =head1 SEE ALSO
 
 L<GD::Graph>
 
-C<GD::Graph::pie> for an example of a similar plotting API.
+L<GD::Graph::pie>
 
-L<Radial> - Acceptable
-
-L<Google::Chart::Type::Radar> - Broken
-
-=head1 ORIGINAL AUTHOR
-
-Copyright 2003 by Brad J. Murray
+C<http://www.phreeow.net/radar/>
 
 =head1 AUTHOR
 
-Gene Boggs <gene@cpan.org>
+Brad J. Murray E<lt>bjm@phreeow.netE<gt>
+
+CPAN distribution by Gene Boggs E<lt>gene@cpan.orgE<gt>
+
+GD::Graph by Martien Verbruggen E<lt>mgjv@tradingpost.com.auE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Gene Boggs.
+Copyright 2003 by Brad J. Murray
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
 
 =cut
